@@ -41,18 +41,13 @@ static const string iconDesc(
 
 static std::string get_iconpath()
 {
-    string iconpath(DATADIR "/icon.png");
-    if (nullptr != g_config) {
-        if (!g_config->get("msiconpath", iconpath)) {
-            std::string datadir;
-            if (g_config->get("pkgdatadir", datadir)) {
-                iconpath = path_cat(datadir, "icon.png");
-            }
+    std::string iconpath;
+    if (!getOptionValue("msiconpath", iconpath)) {
+        iconpath = path_cat(g_datadir, "icon.png");
+        if (!path_exists(iconpath)) {
+            iconpath.clear();
         }
     }
-    if (!path_exists(iconpath)) {
-        iconpath.clear();
-    }
     return iconpath;
 }
 
