@@ -15,8 +15,6 @@
  * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#include "config.h"
-
 #include "ohplaylist.hxx"
 
 #include <stdlib.h>
@@ -123,7 +121,7 @@ OHPlaylist::OHPlaylist(UpMpd *dev,  UpMpdOpenHome *udev, unsigned int cssleep)
             LOGDEB("ohPlaylist: cache restore done" << endl);
         }
     }
-    keepconsume = g_config->getBool("keepconsume", false);
+    keepconsume = getBoolOptionValue("keepconsume", false);
     m_dev->getmpdcli()->subscribe(
         MPDCli::MpdQueueEvt|MPDCli::MpdPlayerEvt|MPDCli::MpdOptsEvt,
         std::bind(&OHService::onEvent, this, _1));
@@ -258,7 +256,7 @@ bool OHPlaylist::makeIdArray(string& out)
         }
     }
 
-    for (const auto entry : m_metacache) {
+    for (const auto& entry : m_metacache) {
         LOGDEB("OHPlaylist::makeIdArray: dropping uri " << entry.first << endl);
     }
 
